Products  What's New  Explore SAP  Products  What's New  Explore SAP
  * [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning)
  * Architecture Decisions
